#' Creating data frame with items and topics
#'
#' Topics are extracted from XML files and written to a data frame that
#' shows which items belong to which topics.
#'
#' @param items A character vector with names of the items. Needs to
#' correspond to the folder names which contain the XML files.
#' @param xmlfiles Vector of names of index files, often something like
#' `<item>.xml`. Need to be in the same order as items!
#' @param xmlpath Path to folder where XML definitions of items live.
#' @return Data frame.
#' @export
#' @examples
#' # tbd
extract_topics <- function(items, xmlfiles, xmlpath) {

  out <- NULL
  i <- 1

  for (item in items) {

    index_file <- paste0(xmlpath, item, "/", xmlfiles[i])
    suppressWarnings(
      fnames <- gsub("^<card src=.*/(.*)./>$", "\\1",
                           grep("^<card src=", trimws(readLines(index_file)),
                                value = TRUE))
    )

    topic <- NULL
    for (fname in fnames) {
      suppressWarnings(
        topic <- c(topic, gsub("^<card type=.(.*).>$", "\\1",
          grep("^<card type=",
            trimws(readLines(paste(xmlpath, item, fname, sep = "/"))),
            value = TRUE)))
      )
    }
    out <- rbind(out, data.frame(item, file_name = fnames, topic))
    i <- i + 1
  }

  out <- out[order(out$item), ]
  rownames(out) <- NULL
  out
}

